==> blesta-5.10.2.zip: blesta/language/fr_fr/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.!success.add_created'] = '%1$s a été créé avec succès !';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s a été modifié avec succès !';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s a été supprimé avec succès !';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s est le groupe par défaut et ne peut être supprimé.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Supprime la possibilité pour les clients de définir leur propre nom d\'utilisateur.';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Cochez cette case pour envoyer un email de vérification lorsqu\'un nouveau login est créé ou qu\'un client change d\'email. Un avis apparaîtra sur le profil du client jusqu\'à ce qu\'il soit vérifié.';
$lang['AdminCompanyGroups.index.page_title'] = 'Paramètres > Entreprise > Groupes de clients';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Groupes de clients';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Créer un groupe';
$lang['AdminCompanyGroups.index.text_name'] = 'Nom';
$lang['AdminCompanyGroups.index.text_description'] = 'Description';
$lang['AdminCompanyGroups.index.text_clients'] = 'Nombre de clients';
$lang['AdminCompanyGroups.index.text_options'] = 'Options';
$lang['AdminCompanyGroups.index.option_edit'] = 'Editer';
$lang['AdminCompanyGroups.index.option_delete'] = 'Supprimer';
$lang['AdminCompanyGroups.index.no_results'] = 'Il n\'y a pas de groupes de clients.';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Etes-vous sûr de vouloir supprimer ce groupe de clients ? Tous les clients de ce groupe seront déplacés vers le groupe par défaut.';
$lang['AdminCompanyGroups.add.page_title'] = 'Paramètres > Entreprise > Groupes de clients > Créer un groupe';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Créer un groupe';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Options de base';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Options de facturation et d\'imputation';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Frais de retard';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Livraison de la facture';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Avis';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Paramètres généraux du client';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Champs obligatoires pour le client';
$lang['AdminCompanyGroups.add.field_name'] = 'Nom';
$lang['AdminCompanyGroups.add.field_color'] = 'Couleur';
$lang['AdminCompanyGroups.add.field_description'] = 'Description';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Méthodes de livraison des factures';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Utiliser les paramètres de l\'entreprise (décocher pour spécifier ci-dessous)';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Utiliser les adresses électroniques comme noms d\'utilisateur';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Activer la vérification du courrier électronique';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Créer un groupe';
$lang['AdminCompanyGroups.edit.page_title'] = 'Réglages > Entreprise > Groupes de clients > Modifier le groupe';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Groupe d\'édition';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Options de base';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Options de facturation et d\'imputation';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Frais de retard';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Livraison de la facture';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Avis';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Paramètres généraux du client';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Champs obligatoires pour le client';
$lang['AdminCompanyGroups.edit.field_name'] = 'Nom';
$lang['AdminCompanyGroups.edit.field_color'] = 'Couleur';
$lang['AdminCompanyGroups.edit.field_description'] = 'Description';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Méthodes de livraison des factures';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Utiliser les paramètres de l\'entreprise (décocher pour spécifier ci-dessous)';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Utiliser les adresses électroniques comme noms d\'utilisateur';
$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Groupe d\'édition';

==> blesta-5.11.4.zip: blesta/language/fr_fr/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.!success.add_created'] = '%1$s a été créé avec succès !';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s a été modifié avec succès !';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s a été supprimé avec succès !';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s est le groupe par défaut et ne peut être supprimé.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Supprime la possibilité pour les clients de définir leur propre nom d\'utilisateur.';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Cochez cette case pour envoyer un email de vérification lorsqu\'un nouveau login est créé ou qu\'un client change d\'email. Un avis apparaîtra sur le profil du client jusqu\'à ce qu\'il soit vérifié.';
$lang['AdminCompanyGroups.index.page_title'] = 'Paramètres > Entreprise > Groupes de clients';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Groupes de clients';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Créer un groupe';
$lang['AdminCompanyGroups.index.text_name'] = 'Nom';
$lang['AdminCompanyGroups.index.text_description'] = 'Description';
$lang['AdminCompanyGroups.index.text_clients'] = 'Nombre de clients';
$lang['AdminCompanyGroups.index.text_options'] = 'Options';
$lang['AdminCompanyGroups.index.option_edit'] = 'Editer';
$lang['AdminCompanyGroups.index.option_delete'] = 'Supprimer';
$lang['AdminCompanyGroups.index.no_results'] = 'Il n\'y a pas de groupes de clients.';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Etes-vous sûr de vouloir supprimer ce groupe de clients ? Tous les clients de ce groupe seront déplacés vers le groupe par défaut.';
$lang['AdminCompanyGroups.add.page_title'] = 'Paramètres > Entreprise > Groupes de clients > Créer un groupe';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Créer un groupe';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Options de base';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Options de facturation et d\'imputation';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Frais de retard';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Livraison de la facture';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Avis';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Paramètres généraux du client';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Champs obligatoires pour le client';
$lang['AdminCompanyGroups.add.field_name'] = 'Nom';
$lang['AdminCompanyGroups.add.field_color'] = 'Couleur';
$lang['AdminCompanyGroups.add.field_description'] = 'Description';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Méthodes de livraison des factures';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Utiliser les paramètres de l\'entreprise (décocher pour spécifier ci-dessous)';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Utiliser les adresses électroniques comme noms d\'utilisateur';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Activer la vérification du courrier électronique';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Créer un groupe';
$lang['AdminCompanyGroups.edit.page_title'] = 'Réglages > Entreprise > Groupes de clients > Modifier le groupe';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Groupe d\'édition';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Options de base';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Options de facturation et d\'imputation';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Frais de retard';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Livraison de la facture';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Avis';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Paramètres généraux du client';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Champs obligatoires pour le client';
$lang['AdminCompanyGroups.edit.field_name'] = 'Nom';
$lang['AdminCompanyGroups.edit.field_color'] = 'Couleur';
$lang['AdminCompanyGroups.edit.field_description'] = 'Description';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Méthodes de livraison des factures';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Utiliser les paramètres de l\'entreprise (décocher pour spécifier ci-dessous)';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Utiliser les adresses électroniques comme noms d\'utilisateur';
$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Groupe d\'édition';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Passerelles autorisées';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Passerelles autorisées';
